% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/MutationProfiling.R
\name{binMutationsByRegion}
\alias{binMutationsByRegion}
\title{Aggregate mutations by region}
\usage{
binMutationsByRegion(mutations_array, regionDefinition = IMGT_V_NO_CDR3)
}
\arguments{
\item{mutations_array}{\code{array} containing the mutations (R/S) with the names
indicating the nucleotide positions of the mutations.}

\item{regionDefinition}{\code{\link{RegionDefinition}} object defining the regions
                            and boundaries of the Ig sequences.}
}
\value{
An \code{array} of R/S mutations binned across all the unique regions defined
by \code{regionDefinition}.
}
\description{
\code{binMutationsByRegion} takes an array of observed mutations (e.g. from
\code{\link{calcObservedMutations}}) and bins them by the different regions defined in the
\code{regionDefinition}.
}
\details{
Note, only the part of sequences defined in \code{regionDefinition} are analyzed.
For example, if the default \link{IMGT_V_NO_CDR3} definition is used, then mutations
in positions beyond 312 will be ignored.
}
\examples{
# Generate a random mutation array
numbOfMutations <- sample(3:10, 1)
posOfMutations <- sort(sample(330, numbOfMutations))
mutationTypes <- sample(c("R","S"), length(posOfMutations), replace=TRUE)
mutations_array <- array(mutationTypes, dimnames=list(posOfMutations))

# Random mutations
binMutationsByRegion(mutations_array, regionDefinition=IMGT_V_NO_CDR3)
}
\seealso{
See \code{\link{calcDBObservedMutations}} for identifying and counting the
number of observed mutations.
This function is also used in \code{\link{calcObservedMutations}}.
}

