% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/MutationProfiling.R
\name{calcDBExpectedMutations}
\alias{calcDBExpectedMutations}
\title{Calculate expected mutation frequencies}
\usage{
calcDBExpectedMutations(db, sequenceColumn = "SEQUENCE_IMGT",
  germlineColumn = "GERMLINE_IMGT_D_MASK", targetingModel = HS5FModel,
  regionDefinition = IMGT_V_NO_CDR3, nproc = 1)
}
\arguments{
\item{db}{\code{data.frame} containing sequence data.}

\item{sequenceColumn}{\code{character} name of the column containing input
sequences.}

\item{germlineColumn}{\code{character} name of the column containing
the germline or reference sequence.}

\item{targetingModel}{\link{TargetingModel} object. Default is \link{HS5FModel}.}

\item{regionDefinition}{\link{RegionDefinition} object defining the regions
and boundaries of the Ig sequences.}

\item{nproc}{\code{numeric} number of cores to distribute the operation
                            over. If the cluster has already been set the call function with
                            \code{nproc} = 0 to not reset or reinitialize. Default is
                            \code{nproc} = 1.}
}
\value{
A modified \code{db} \code{data.frame} with expected mutation frequencies
          for each region defined in \code{regionDefinition}.

          The columns names are dynamically created based on the regions in
          \code{regionDefinition}. For example, when using the default \link{IMGT_V_NO_CDR3}
          definition, which defines positions for CDR and FWR, the following columns are
          added:
          \itemize{
            \item  \code{EXPECTED_CDR_R}:  number of replacement mutations in CDR1 and
                                           CDR2 of the V-segment.
            \item  \code{EXPECTED_CDR_S}:  number of silent mutations in CDR1 and CDR2
                                           of the V-segment.
            \item  \code{EXPECTED_FWR_R}:  number of replacement mutations in FWR1,
                                           FWR2 and FWR3 of the V-segment.
            \item  \code{EXPECTED_FWR_S}:  number of silent mutations in FWR1, FWR2 and
                                           FWR3 of the V-segment.
          }
}
\description{
\code{calcDBExpectedMutations} calculates the expected mutation frequencies for each
sequence in the input \code{data.frame}.
}
\details{
Only the part of the sequences defined in \code{regionDefinition} are analyzed.
For example, when using the default \link{IMGT_V_NO_CDR3} definition, mutations in
positions beyond 312 will be ignored.
}
\examples{
# Load example data
library("alakazam")
dbPath <- system.file("extdata", "Influenza.tab", package="shm")
db <- readChangeoDb(dbPath)
# Subset data for demo purposes
db <- db[1:10, ]

# Run calcDBExpectedMutations()
db <- calcDBExpectedMutations(db,
                              sequenceColumn="SEQUENCE_IMGT",
                              germlineColumn="GERMLINE_IMGT_D_MASK",
                              regionDefinition=IMGT_V_NO_CDR3,
                              nproc=1)
}
\seealso{
\link{calcExpectedMutations} is called by this function to calculate the
expected mutation frequencies. See \link{calcDBObservedMutations} for getting observed
mutation counts.
}

