% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/MutationProfiling.R
\name{calcExpectedMutations}
\alias{calcExpectedMutations}
\title{Calculate expected mutation frequencies of a sequence}
\usage{
calcExpectedMutations(germlineSeq, inputSeq = NULL,
  targetingModel = HS5FModel, regionDefinition = IMGT_V_NO_CDR3)
}
\arguments{
\item{germlineSeq}{germline (reference) sequence.}

\item{inputSeq}{input (observed) sequence. If this is not \code{NULL},
then \code{germlineSeq} will be processed to be the same
same length as \code{inputSeq} and positions in
\code{germlineSeq} corresponding to positions with Ns in
\code{inputSeq} will also be assigned an N.}

\item{targetingModel}{\link{TargetingModel} object. Default is \link{HS5FModel}.}

\item{regionDefinition}{\link{RegionDefinition} object defining the regions
                            and boundaries of the Ig sequences.}
}
\value{
A \code{numeric} vector of the expected frequencies of mutations in the
          regions in the \code{regionDefinition}. For example, when using the default
          \link{IMGT_V_NO_CDR3} definition, which defines positions for CDR and
          FWR, the following columns are calculated:
          \itemize{
             \item  \code{EXPECTED_CDR_R}:  number of replacement mutations in CDR1 and
                                            CDR2 of the V-segment.
             \item  \code{EXPECTED_CDR_S}:  number of silent mutations in CDR1 and CDR2
                                            of the V-segment.
             \item  \code{EXPECTED_FWR_R}:  number of replacement mutations in FWR1,
                                            FWR2 and FWR3 of the V-segment.
             \item  \code{EXPECTED_FWR_S}:  number of silent mutations in FWR1, FWR2 and
                                            FWR3 of the V-segment.
           }
}
\description{
\code{calcExpectedMutations} calculates the expected mutation
frequencies of a given sequence. This is primarily a helper function for
\link{calcDBExpectedMutations}.
}
\details{
\code{calcExpectedMutations} calculates the expected mutation frequencies of a
given sequence and its germline.

Note, only the part of the sequences defined in \code{regionDefinition} are analyzed.
For example, when using the default \link{IMGT_V_NO_CDR3} definition, mutations in
positions beyond 312 will be ignored.
}
\examples{
dbPath <- system.file("extdata", "Influenza.tab", package="shm")
db <- readChangeoDb(dbPath)

# Extracting the first entry in the sample db to use for input and germline sequences.
inputSeq <- db[1, "SEQUENCE_IMGT"]
germlineSeq <-  db[1, "GERMLINE_IMGT_D_MASK"]

# Identify all mutations in the sequence
expectedFreq <- calcExpectedMutations(inputSeq, germlineSeq)

# Identify only mutations the V segment minus CDR3
expectedFreq <- calcObservedMutations(inputSeq, germlineSeq, regionDefinition=IMGT_V_NO_CDR3)
}
\seealso{
\link{calcDBExpectedMutations} calls this function.
To create a custom \code{targetingModel} see \link{createTargetingModel}.
See \link{calcObservedMutations} for getting observed mutation counts.
}

