% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/TargetingModels.R
\name{createSubstitutionMatrix}
\alias{createSubstitutionMatrix}
\title{Builds a substitution model}
\usage{
createSubstitutionMatrix(db, model = c("RS", "S"),
  sequenceColumn = "SEQUENCE_IMGT", germlineColumn = "GERMLINE_IMGT_D_MASK",
  vCallColumn = "V_CALL", multipleMutation = c("independent", "ignore"))
}
\arguments{
\item{db}{data.frame containing sequence data.}

\item{model}{type of model to create. The default model, "RS", creates
a model by counting both replacement and silent mutations.
The "S" specification builds a model by counting only
silent mutations.}

\item{sequenceColumn}{name of the column containing IMGT-gapped sample sequences.}

\item{germlineColumn}{name of the column containing IMGT-gapped germline sequences.}

\item{vCallColumn}{name of the column containing the V-segment allele call.}

\item{multipleMutation}{string specifying how to handle multiple mutations occuring
                            within the same 5-mer. If \code{"independent"} then multiple
                            mutations within the same 5-mer are counted indepedently.
                            If \code{"ignore"} then 5-mers with multiple mutations are
                            excluded from the total mutation tally.}
}
\value{
A 4x1024 matrix of column normalized substitution rates for each 5-mer motif with
          row names defining the center nucleotide, one of \code{c("A", "C", "G", "T")},
          and column names defining the 5-mer nucleotide sequence.
}
\description{
\code{createSubstitutionMatrix} builds a 5-mer nucleotide substitution model by counting
the number of substitution mutations occuring in the center position for all 5-mer
motifs.
}
\examples{
# Load example data
library(alakazam)
file <- system.file("extdata", "Influenza.tab", package="shm")
db <- readChangeoDb(file)

# Create model using all mutations
sub <- createSubstitutionMatrix(db)

# Create model using only silent mutations and ignore multiple mutations
sub <- createSubstitutionMatrix(db, model="S", multipleMutation="ignore")
}
\references{
\enumerate{
  \item  Yaari G, et al. Models of somatic hypermutation targeting and substitution based
           on synonymous mutations from high-throughput immunoglobulin sequencing data.
           Front Immunol. 2013 4(November):358.
 }
}
\seealso{
Other targeting model functions: \code{\link{calcTargetingDistance}};
  \code{\link{createMutabilityMatrix}};
  \code{\link{createTargetingMatrix}};
  \code{\link{createTargetingModel}};
  \code{\link{extendMutabilityMatrix}};
  \code{\link{extendSubstitutionMatrix}};
  \code{\link{plotMutability}};
  \code{\link{rescaleMutability}};
  \code{\link{writeTargetingDistance}}
}

