% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/TargetingModels.R
\name{createTargetingModel}
\alias{createTargetingModel}
\title{Creates a TargetingModel}
\usage{
createTargetingModel(db, model = c("RS", "S"),
  sequenceColumn = "SEQUENCE_IMGT", germlineColumn = "GERMLINE_IMGT_D_MASK",
  vCallColumn = "V_CALL", multipleMutation = c("independent", "ignore"),
  modelName = "", modelDescription = "", modelSpecies = "",
  modelCitation = "", modelDate = NULL)
}
\arguments{
\item{db}{data.frame containing sequence data.}

\item{model}{type of model to create. The default model, "RS", creates
a model by counting both replacement and silent mutations.
The "S" specification builds a model by counting only
silent mutations.}

\item{sequenceColumn}{name of the column containing IMGT-gapped sample sequences.}

\item{germlineColumn}{name of the column containing IMGT-gapped germline sequences.}

\item{vCallColumn}{name of the column containing the V-segment allele calls.}

\item{multipleMutation}{string specifying how to handle multiple mutations occuring
within the same 5-mer. If \code{"independent"} then multiple
mutations within the same 5-mer are counted indepedently.
If \code{"ignore"} then 5-mers with multiple mutations are
excluded from the total mutation tally.}

\item{modelName}{name of the model.}

\item{modelDescription}{description of the model and its source data.}

\item{modelSpecies}{genus and species of the source sequencing data.}

\item{modelCitation}{publication source.}

\item{modelDate}{date the model was built. If \code{NULL} the current date
will be used.}
}
\value{
A \code{\link{TargetingModel}} object.
}
\description{
\code{createTargetingModel} creates a \code{TargetingModel}.
}
\examples{
# Load example data
library(alakazam)
file <- system.file("extdata", "Influenza.tab", package="shm")
db <- readChangeoDb(file)

# Create model using all mutations
model <- createTargetingModel(db)

# Create model using only silent mutations and ignore multiple mutations
model <- createTargetingModel(db, model="S", multipleMutation="ignore")
}
\references{
\enumerate{
  \item  Yaari G, et al. Models of somatic hypermutation targeting and substitution based
           on synonymous mutations from high-throughput immunoglobulin sequencing data.
           Front Immunol. 2013 4(November):358.
 }
}
\seealso{
See \link{TargetingModel} for the return object.

Other targeting model functions: \code{\link{calcTargetingDistance}};
  \code{\link{createMutabilityMatrix}};
  \code{\link{createSubstitutionMatrix}};
  \code{\link{createTargetingMatrix}};
  \code{\link{extendMutabilityMatrix}};
  \code{\link{extendSubstitutionMatrix}};
  \code{\link{plotMutability}};
  \code{\link{rescaleMutability}};
  \code{\link{writeTargetingDistance}}
}

